@@ -15,16 +15,26 @@
 
 import os
 
+import debtcollector
+
+__all__ = [
+    'subprocess',
+]
+
 try:
     import eventlet.patcher
 except ImportError:
     _patched_socket = False
 else:
     # In tests patching happens later, so we'll rely on environment variable
-    _patched_socket = (eventlet.patcher.is_monkey_patched('socket') or
-                       os.environ.get('TEST_EVENTLET', False))
+    _patched_socket = eventlet.patcher.is_monkey_patched('socket') or bool(
+        os.environ.get('TEST_EVENTLET', False)
+    )
 
 if not _patched_socket:
     import subprocess
 else:
-    from eventlet.green import subprocess   # noqa
+    debtcollector.deprecate(
+        "Eventlet support is deprecated and will be soon removed."
+    )
+    from eventlet.green import subprocess  # type: ignore
