@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from collections.abc import Sequence
 import os
 import re
 import shutil
@@ -28,12 +29,12 @@ if sys.platform != 'win32':
     import pwd
 
 
-def _getuid(user):
+def _getuid(user: str) -> int:
     """Return uid for user."""
     return pwd.getpwnam(user).pw_uid
 
 
-def realpath(path):
+def realpath(path: str) -> str:
     """Return the real absolute path.
 
     If the execution directory does not exist, os.getcwd() raises a
@@ -46,17 +47,17 @@ def realpath(path):
         return ''
 
 
-class CommandFilter(object):
+class CommandFilter:
     """Command filter only checking that the 1st argument matches exec_path."""
 
-    def __init__(self, exec_path, run_as, *args):
+    def __init__(self, exec_path: str, run_as: str, *args: str) -> None:
         self.name = ''
         self.exec_path = exec_path
         self.run_as = run_as
         self.args = args
-        self.real_exec = None
+        self.real_exec: str | None = None
 
-    def get_exec(self, exec_dirs=None):
+    def get_exec(self, exec_dirs: list[str] | None = None) -> str | None:
         """Returns existing executable, or empty string if none found."""
         exec_dirs = exec_dirs or []
         if self.real_exec is not None:
@@ -72,7 +73,7 @@ class CommandFilter(object):
                     break
         return self.real_exec
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
         """Only check that the first argument (command) matches exec_path."""
         if userargs:
             base_path_matches = os.path.basename(self.exec_path) == userargs[0]
@@ -80,18 +81,20 @@ class CommandFilter(object):
             return exact_path_matches or base_path_matches
         return False
 
-    def preexec(self):
+    def preexec(self) -> None:
         """Setuid in subprocess right before command is invoked."""
         if self.run_as != 'root':
             os.setuid(_getuid(self.run_as))
 
-    def get_command(self, userargs, exec_dirs=None):
+    def get_command(
+        self, userargs: list[str], exec_dirs: list[str] | None = None
+    ) -> list[str]:
         """Returns command to execute."""
         exec_dirs = exec_dirs or []
         to_exec = self.get_exec(exec_dirs=exec_dirs) or self.exec_path
-        return [to_exec] + userargs[1:]
+        return [to_exec] + list(userargs[1:])
 
-    def get_environment(self, userargs):
+    def get_environment(self, userargs: list[str]) -> dict[str, str] | None:
         """Returns specific environment to set, None if none."""
         return None
 
@@ -99,13 +102,13 @@ class CommandFilter(object):
 class RegExpFilter(CommandFilter):
     """Command filter doing regexp matching for every argument."""
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
         # Early skip if command or number of args don't match
-        if (not userargs or len(self.args) != len(userargs)):
+        if not userargs or len(self.args) != len(userargs):
             # DENY: argument numbers don't match
             return False
         # Compare each arg (anchoring pattern explicitly at end of string)
-        for (pattern, arg) in zip(self.args, userargs):
+        for pattern, arg in zip(self.args, userargs):
             try:
                 if not re.match(pattern + '$', arg):
                     # DENY: Some arguments did not match
@@ -120,25 +123,25 @@ class RegExpFilter(CommandFilter):
 class PathFilter(CommandFilter):
     """Command filter checking that path arguments are within given dirs
 
-        One can specify the following constraints for command arguments:
-            1) pass     - pass an argument as is to the resulting command
-            2) some_str - check if an argument is equal to the given string
-            3) abs path - check if a path argument is within the given base dir
+    One can specify the following constraints for command arguments:
+        1) pass     - pass an argument as is to the resulting command
+        2) some_str - check if an argument is equal to the given string
+        3) abs path - check if a path argument is within the given base dir
 
-        A typical rootwrapper filter entry looks like this:
-            # cmdname: filter name, raw command, user, arg_i_constraint [, ...]
-            chown: PathFilter, /bin/chown, root, nova, /var/lib/images
+    A typical rootwrapper filter entry looks like this:
+        # cmdname: filter name, raw command, user, arg_i_constraint [, ...]
+        chown: PathFilter, /bin/chown, root, nova, /var/lib/images
 
     """
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
         if not userargs or len(userargs) < 2:
             return False
 
         arguments = userargs[1:]
 
         equal_args_num = len(self.args) == len(arguments)
-        exec_is_valid = super(PathFilter, self).match(userargs)
+        exec_is_valid = super().match(userargs)
         args_equal_or_pass = all(
             arg == 'pass' or arg == value
             for arg, value in zip(self.args, arguments)
@@ -150,66 +153,49 @@ class PathFilter(CommandFilter):
             if os.path.isabs(arg)  # arguments specifying abs paths
         )
 
-        return (equal_args_num and
-                exec_is_valid and
-                args_equal_or_pass and
-                paths_are_within_base_dirs)
+        return (
+            equal_args_num
+            and exec_is_valid
+            and args_equal_or_pass
+            and paths_are_within_base_dirs
+        )
 
-    def get_command(self, userargs, exec_dirs=None):
+    def get_command(
+        self, userargs: list[str], exec_dirs: list[str] | None = None
+    ) -> list[str]:
         exec_dirs = exec_dirs or []
         command, arguments = userargs[0], userargs[1:]
 
         # convert path values to canonical ones; copy other args as is
-        args = [realpath(value) if os.path.isabs(arg) else value
-                for arg, value in zip(self.args, arguments)]
+        args = [
+            realpath(value) if os.path.isabs(arg) else value
+            for arg, value in zip(self.args, arguments)
+        ]
 
-        return super(PathFilter, self).get_command([command] + args,
-                                                   exec_dirs)
+        return super().get_command([command] + args, exec_dirs)
 
 
 class KillFilter(CommandFilter):
     """Specific filter for the kill calls.
 
-       1st argument is the user to run /bin/kill under
-       2nd argument is the location of the affected executable
-           if the argument is not absolute, it is checked against $PATH
-       Subsequent arguments list the accepted signals (if any)
+    1st argument is the user to run /bin/kill under
+    2nd argument is the location of the affected executable
+        if the argument is not absolute, it is checked against $PATH
+    Subsequent arguments list the accepted signals (if any)
 
-       This filter relies on /proc to accurately determine affected
-       executable, so it will only work on procfs-capable systems (not OSX).
+    This filter relies on /proc to accurately determine affected
+    executable, so it will only work on procfs-capable systems (not OSX).
     """
 
-    def __init__(self, *args):
-        super(KillFilter, self).__init__("/bin/kill", *args)
+    def __init__(self, *args: str) -> None:
+        super().__init__("/bin/kill", *args)
 
-    @staticmethod
-    def _program_path(command):
-        """Try to determine the full path for command.
-
-        Return command if the full path cannot be found.
-        """
-
-        # shutil.which() was added to Python 3.3
-        if hasattr(shutil, 'which'):
-            return shutil.which(command)
-
-        if os.path.isabs(command):
-            return command
-
-        path = os.environ.get('PATH', os.defpath).split(os.pathsep)
-        for dir in path:
-            program = os.path.join(dir, command)
-            if os.path.isfile(program):
-                return program
-
-        return command
-
-    def _program(self, pid):
+    def _program(self, pid: int) -> str | None:
         """Determine the program associated with pid"""
 
         try:
-            command = os.readlink("/proc/%d/exe" % int(pid))
-        except (ValueError, EnvironmentError):
+            command = os.readlink(f"/proc/{pid}/exe")
+        except (ValueError, OSError):
             # Incorrect PID
             return None
 
@@ -221,7 +207,7 @@ class KillFilter(CommandFilter):
         # NOTE(dprince): /proc/PID/exe may have ' (deleted)' on
         # the end if an executable is updated or deleted
         if command.endswith(" (deleted)"):
-            command = command[:-len(" (deleted)")]
+            command = command[: -len(" (deleted)")]
 
         if os.path.isfile(command):
             return command
@@ -230,10 +216,10 @@ class KillFilter(CommandFilter):
         # a ';......' or '.#prelink#......' suffix etc.
         # So defer to /proc/PID/cmdline in that case.
         try:
-            with open("/proc/%d/cmdline" % int(pid)) as pfile:
+            with open(f"/proc/{pid}/cmdline") as pfile:
                 cmdline = pfile.read().partition('\0')[0]
 
-            cmdline = self._program_path(cmdline)
+            cmdline = shutil.which(cmdline) or cmdline
             if os.path.isfile(cmdline):
                 command = cmdline
 
@@ -241,10 +227,10 @@ class KillFilter(CommandFilter):
             # as that will allow killing a process where the exe
             # has been removed from the system rather than updated.
             return command
-        except EnvironmentError:
+        except OSError:
             return None
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
         if not userargs or userargs[0] != "kill":
             return False
         args = list(userargs)
@@ -262,7 +248,11 @@ class KillFilter(CommandFilter):
                 # No signal requested, but filter requires specific signal
                 return False
 
-        command = self._program(args[1])
+        try:
+            pid = int(args[1])
+        except ValueError:
+            return False
+        command = self._program(pid)
         if not command:
             return False
 
@@ -271,27 +261,31 @@ class KillFilter(CommandFilter):
         if os.path.isabs(kill_command):
             return kill_command == command
 
-        return (os.path.isabs(command) and
-                kill_command == os.path.basename(command) and
-                os.path.dirname(command) in os.environ.get('PATH', ''
-                                                           ).split(':'))
+        return (
+            os.path.isabs(command)
+            and kill_command == os.path.basename(command)
+            and os.path.dirname(command)
+            in os.environ.get('PATH', '').split(':')
+        )
 
 
 class ReadFileFilter(CommandFilter):
     """Specific filter for the utils.read_file_as_root call."""
 
-    def __init__(self, file_path, *args):
+    def __init__(self, file_path: str, *args: str) -> None:
         self.file_path = file_path
-        super(ReadFileFilter, self).__init__("/bin/cat", "root", *args)
+        super().__init__("/bin/cat", "root", *args)
 
-    def match(self, userargs):
-        return (userargs == ['cat', self.file_path])
+    def match(self, userargs: list[str] | None) -> bool:
+        return userargs == ['cat', self.file_path]
 
 
 class IpFilter(CommandFilter):
     """Specific filter for the ip utility to that does not match exec."""
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
+        if not userargs:
+            return False
         if userargs[0] == 'ip':
             # Avoid the 'netns exec' command here
             for a, b in zip(userargs[1:], userargs[2:]):
@@ -299,6 +293,7 @@ class IpFilter(CommandFilter):
                     return b not in EXEC_VARS
             else:
                 return True
+        return False
 
 
 class EnvFilter(CommandFilter):
@@ -308,7 +303,7 @@ class EnvFilter(CommandFilter):
     leading env A=B.. strings appropriately.
     """
 
-    def _extract_env(self, arglist):
+    def _extract_env(self, arglist: Sequence[str]) -> set[str]:
         """Extract all leading NAME=VALUE arguments from arglist."""
 
         envs = set()
@@ -318,8 +313,8 @@ class EnvFilter(CommandFilter):
             envs.add(arg.partition('=')[0])
         return envs
 
-    def __init__(self, exec_path, run_as, *args):
-        super(EnvFilter, self).__init__(exec_path, run_as, *args)
+    def __init__(self, exec_path: str, run_as: str, *args: str) -> None:
+        super().__init__(exec_path, run_as, *args)
 
         env_list = self._extract_env(self.args)
         # Set exec_path to X when args are in the form of
@@ -327,7 +322,9 @@ class EnvFilter(CommandFilter):
         if "env" in exec_path and len(env_list) < len(self.args):
             self.exec_path = self.args[len(env_list)]
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
+        if not userargs:
+            return False
         # ignore leading 'env'
         if userargs[0] == 'env':
             userargs.pop(0)
@@ -339,13 +336,16 @@ class EnvFilter(CommandFilter):
         # extract all env args
         user_envs = self._extract_env(userargs)
         filter_envs = self._extract_env(self.args)
-        user_command = userargs[len(user_envs):len(user_envs) + 1]
+        user_command = userargs[len(user_envs) : len(user_envs) + 1]
 
         # match first non-env argument with CommandFilter
-        return (super(EnvFilter, self).match(user_command) and
-                len(filter_envs) and user_envs == filter_envs)
+        return bool(
+            super().match(user_command)
+            and len(filter_envs)
+            and user_envs == filter_envs
+        )
 
-    def exec_args(self, userargs):
+    def exec_args(self, userargs: list[str]) -> list[str]:
         args = userargs[:]
 
         # ignore leading 'env'
@@ -358,11 +358,13 @@ class EnvFilter(CommandFilter):
 
         return args
 
-    def get_command(self, userargs, exec_dirs=[]):
-        to_exec = self.get_exec(exec_dirs=exec_dirs) or self.exec_path
+    def get_command(
+        self, userargs: list[str], exec_dirs: list[str] | None = None
+    ) -> list[str]:
+        to_exec = self.get_exec(exec_dirs=exec_dirs or []) or self.exec_path
         return [to_exec] + self.exec_args(userargs)[1:]
 
-    def get_environment(self, userargs):
+    def get_environment(self, userargs: list[str]) -> dict[str, str] | None:
         env = os.environ.copy()
 
         # ignore leading 'env'
@@ -381,23 +383,26 @@ class EnvFilter(CommandFilter):
 
 
 class ChainingFilter(CommandFilter):
-    def exec_args(self, userargs):
+    def exec_args(self, userargs: list[str]) -> list[str]:
         return []
 
 
 class IpNetnsExecFilter(ChainingFilter):
     """Specific filter for the ip utility to that does match exec."""
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
         # Network namespaces currently require root
         # require <ns> argument
-        if self.run_as != "root" or len(userargs) < 4:
+        if not userargs or self.run_as != "root" or len(userargs) < 4:
             return False
 
-        return (userargs[0] == 'ip' and userargs[1] in NETNS_VARS and
-                userargs[2] in EXEC_VARS)
+        return (
+            userargs[0] == 'ip'
+            and userargs[1] in NETNS_VARS
+            and userargs[2] in EXEC_VARS
+        )
 
-    def exec_args(self, userargs):
+    def exec_args(self, userargs: list[str]) -> list[str]:
         args = userargs[4:]
         if args:
             args[0] = os.path.basename(args[0])
@@ -411,12 +416,12 @@ class ChainingRegExpFilter(ChainingFilter):
     specified as the arguments must be also allowed to execute directly.
     """
 
-    def match(self, userargs):
+    def match(self, userargs: list[str] | None) -> bool:
         # Early skip if number of args is smaller than the filter
-        if (not userargs or len(self.args) > len(userargs)):
+        if not userargs or len(self.args) > len(userargs):
             return False
         # Compare each arg (anchoring pattern explicitly at end of string)
-        for (pattern, arg) in zip(self.args, userargs):
+        for pattern, arg in zip(self.args, userargs):
             try:
                 if not re.match(pattern + '$', arg):
                     # DENY: Some arguments did not match
@@ -427,8 +432,8 @@ class ChainingRegExpFilter(ChainingFilter):
         # ALLOW: All arguments matched
         return True
 
-    def exec_args(self, userargs):
-        args = userargs[len(self.args):]
+    def exec_args(self, userargs: list[str]) -> list[str]:
+        args = userargs[len(self.args) :]
         if args:
             args[0] = os.path.basename(args[0])
         return args
